<a href="https://tiledb.com"><img src="https://github.com/TileDB-Inc/TileDB/raw/dev/doc/source/_static/tiledb-logo_color_no_margin_@4x.png" alt="TileDB logo" width="400"></a>

# TileDB-CF-Py

The TileDB-CF-Py library is a Python library for supporting the NetCDF data model in the [TileDB storage engine](https://github.com/TileDB-Inc/TileDB). TileDB-CF-Py provides readers and writers for viewing and manipulating TileDB arrays and groups using TileDB CF Dataspaces - a special TileDB group that follows the requirements in [docs/source/tiledb-cf-spec.md](documentation/tiledb-cf-spec.md).

:warning: This library is still under initial development and changes may not be backward compatible.

## TileDB Quick Links

  * [Homepage](https://tiledb.com)
  * [Documentation](https://docs.tiledb.com/main/)
  * [Forum](https://forum.tiledb.io/)
  * [Organization](https://github.com/TileDB-Inc/)

## Getting Started

### Quick Installation

This project is available from [PyPI](https://pypi.org/project/tiledb-cf/) and may be installed with ``pip``:

```bash
pip install tiledb-cf
```

### Documentation

Documentation is available at: [https://tiledb-inc.github.io/TileDB-CF-Py](https://tiledb-inc.github.io/TileDB-CF-Py/)

### Example Notebooks

Example Jupyter notebooks are available in the [examples](./examples) folder.


## Development

For information on contributing to this project see the [contributing](documentation/contributing.md) document and the [code of conduct](documentation/code-of-conduct.md).
